@@ -44,7 +44,7 @@ class LiveClient(WebSocketApp):
         self.confirm_heartbeats = 1
         self.store_last_n_heartbeats = self.confirm_heartbeats + 7
         self.heartbeat_interval = 5
-        self.heartbeat_buffer = 0.9
+        self.heartbeat_buffer = 1.5
         time_of_creation = datetime.now()
         self.last_n_heartbeat = [time_of_creation - relativedelta(seconds=i * self.heartbeat_interval) for i in range(-self.store_last_n_heartbeats, 0)]
         # print("RECREATED")
@@ -68,7 +68,7 @@ class LiveClient(WebSocketApp):
                 print(f"{Style.BRIGHT}{Fore.RED}Attempting reconnect @ {Fore.CYAN}{datetime.now()}{Style.RESET_ALL}")
                 restart_successful = self.reconnect()
                 if restart_successful:
-                    print(f"{Style.BRIGHT}{Fore.RED}Successful restart @ {Fore.CYAN}{datetime.now()}{Style.RESET_ALL}")
+                    print(f"{Style.BRIGHT}{Fore.GREEN}Successful restart @ {Fore.CYAN}{datetime.now()}{Style.RESET_ALL}")
                     time.sleep((self.heartbeat_interval + self.heartbeat_buffer))
                     recover_start, recover_end = self.get_largest_diff(self.last_n_heartbeat)
                     # print(f"\t\t\t{len(self.last_n_heartbeat)} - {self.last_n_heartbeat}")
